From 679f3858be68bdb500cf3529aad42dad802d3c39 Mon Sep 17 00:00:00 2001
From: Zzull <bstrazzull@hotmail.fr>
Date: Sun, 25 Sep 2022 22:45:02 +0200
Subject: [PATCH 06/13] gnu: Add java-fasterxml-jackson-dataformat-cbor

* gnu/packages/java.scm (java-fasterxml-jackson-dataformat-cbor): New variable.
---
 gnu/packages/java.scm | 59 +++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 59 insertions(+)

diff --git a/gnu/packages/java.scm b/gnu/packages/java.scm
index eb34cbfb7e..df1b712bbc 100644
--- a/gnu/packages/java.scm
+++ b/gnu/packages/java.scm
@@ -10475,6 +10475,65 @@ (define-public java-fasterxml-jackson-dataformat-smile
 abstractions.")
     (license license:asl2.0))) ; found on wiki.fasterxml.com/JacksonLicensing
 
+(define-public java-fasterxml-jackson-dataformat-cbor
+  (package
+    (name "java-fasterxml-jackson-dataformat-cbor")
+    (version "2.12.2")
+    (source (origin
+              (method git-fetch)
+              (uri (git-reference
+                    (url
+                     "https://github.com/FasterXML/jackson-dataformats-binary")
+                    (commit
+                     (string-append "jackson-dataformats-binary-" version))))
+              (file-name (git-file-name name version))
+              (sha256
+               (base32
+                "1qfi44kk1iy9nwcgb55ksdis4jqfqxqrqqv81y3xgm134ds3j9l2"))))
+    (build-system ant-build-system)
+    (arguments
+     `(#:jar-name "jackson-dataformat-cbor.jar"
+       #:source-dir "cbor/src/main/java"
+       #:test-dir "cbor/src/test"
+       #:test-exclude (list "**/failing/**.java"
+                            "**/GeneratorDeepNestingTest.java"
+                            "**/NumberCoercing32Test.java"
+                            "**/SharedRawGeneratorBufferTest.java"
+                            "**/gen/GeneratorSimpleTest.java"
+                            "**/mapper/BiggerDataTest.java"
+                            "**/mapper/BinaryReadTest.java"
+                            "**/mapper/MapperSimpleReadTest.java"
+                            "**/mapper/NumberArrayBeanTest.java"
+                            "**/mapper/NumberBeanTest.java"
+                            "**/parse/BinaryToStringCoercionTest.java")
+       #:phases
+       (modify-phases %standard-phases
+         (add-before 'configure 'generate-PackageVersion.java
+           (lambda _
+             (let* ((out (string-append
+                          "cbor/src/main/java/com/fasterxml/"
+                          "jackson/dataformat/cbor/PackageVersion.java"))
+                    (in (string-append out ".in")))
+               (copy-file in out)
+               (substitute* out
+                 (("@package@") "com.fasterxml.jackson.dataformat.cbor")
+                 (("@projectversion@") ,version)
+                 (("@projectgroupid@") "com.fasterxml.jackson.dataformat.cbor")
+                 (("@projectartifactid@") "jackson-dataformat-cbor")))
+             #t)))))
+    (inputs
+     (list java-fasterxml-jackson-core-2.12.2
+           java-fasterxml-jackson-databind-2.12.2))
+    (native-inputs
+     (list java-junit
+           java-fasterxml-jackson-annotations))
+    (home-page "https://github.com/FasterXML/jackson-dataformats-binary")
+    (synopsis "Cbor backend for Jackson")
+    (description "Dataformat backends are used to support format alternatives
+to JSON, supported by default.  This is done by sub-classing Jackson core
+abstractions.")
+    (license license:asl2.0))) ; found on wiki.fasterxml.com/JacksonLicensing
+
 (define-public java-hdrhistogram
   (package
     (name "java-hdrhistogram")
-- 
2.38.0

